summaryrefslogtreecommitdiffstats
path: root/pkg/gui/credentials_panel.go
diff options
context:
space:
mode:
authorJesse Duffield <jessedduffield@gmail.com>2020-08-11 20:29:05 +1000
committerJesse Duffield <jessedduffield@gmail.com>2020-08-12 18:47:16 +1000
commit1c0da2967c50d6c8992adddf7c94ad2a4e5451e2 (patch)
tree96bc6597278c4d667a01bd336e0e4cdf02f2ee77 /pkg/gui/credentials_panel.go
parent1b78a42b80098fa2376b33efb3e84a0da56b7ad9 (diff)
update naming
Diffstat (limited to 'pkg/gui/credentials_panel.go')
-rw-r--r--pkg/gui/credentials_panel.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/pkg/gui/credentials_panel.go b/pkg/gui/credentials_panel.go
index d1696b163..3943055a7 100644
--- a/pkg/gui/credentials_panel.go
+++ b/pkg/gui/credentials_panel.go
@@ -8,8 +8,8 @@ import (
type credentials chan string
-// waitForPassUname wait for a username or password input from the credentials popup
-func (gui *Gui) waitForPassUname(passOrUname string) string {
+// promptUserForCredential wait for a username or password input from the credentials popup
+func (gui *Gui) promptUserForCredential(passOrUname string) string {
gui.credentials = make(chan string)
gui.g.Update(func(g *gocui.Gui) error {
credentialsView, _ := g.View("credentials")